from . import netbox
import argparse

def main():
    parser = argparse.ArgumentParser(description="Keep kalm and automate netbox", usage="kalm_netbox <action> \n\n \
               \
               version : 0.0.2 (netbox)\n\
               actions:\n\
               netboxdata                dump netbox data in json \n\
               ansible_inventory         dump ansible inventory\n\
               refresh                   refresh core netbox content\n\
               \
               2023 Knowit Miracle\
               ")
    parser.add_argument('action', metavar='<action>', type=str, nargs='+', help='setup jenkis')
    args = parser.parse_args()
    ready = False

    if args.action[0] == "ansible_inventory":
        netbox.ansible_inventory(args)
        return 0
    

    if args.action[0] == "netboxdata":
        netbox.netboxdata(args)
        return 0
    
    return 0

    

    










import os
import datetime


def get_file_content(file_path):
    with open(file_path, 'r') as f:
        return f.read()
    

def get_file_content_lines(file_path):
    with open(file_path, 'r') as f:
        return f.readlines()
    

def prettyllog(function, action, item, organization, statuscode, text):
  d_date = datetime.datetime.now()
  reg_format_date = d_date.strftime("%Y-%m-%d %I:%M:%S %p")
  print("%-20s: %-12s %20s %-50s %-20s %-4s %-50s " %( reg_format_date, function,action,item,organization,statuscode, text))
